#
# spec file for package python-Glymur
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
# NEP 29: NumPy dropped Python 3.6
%define         skip_python36 1
Name:           python-Glymur
Version:        0.9.3
Release:        1.1
Summary:        Tools for accessing JPEG2000 files
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/quintusdias/glymur
Source:         https://github.com/quintusdias/glymur/archive/v%{version}.tar.gz#/Glymur-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  procps
BuildRequires:  python-rpm-macros
Requires:       python-numpy >= 1.7.1
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     python-lxml
BuildArch:      noarch
# SECTION test requirements
# (importlib_resources for Leap's Python 3.6)
BuildRequires:  %{python_module importlib_resources if %python-base < 3.7}
BuildRequires:  %{python_module lxml}
BuildRequires:  %{python_module numpy >= 1.7.1}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scikit-image}
# /SECTION
%python_subpackages

%description
Python interface to the OpenJPEG library

%prep
%setup -q -n glymur-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/jp2dump
%{python_expand # don't install tests
rm -rf %{buildroot}%{$python_sitelib}/tests
%fdupes %{buildroot}%{$python_sitelib}
}

%check
%pytest

%post
%python_install_alternative jp2dump

%postun
%python_uninstall_alternative jp2dump

%files %{python_files}
%doc README.md CHANGES.txt
%license LICENSE.txt
%python_alternative %{_bindir}/jp2dump
%{python_sitelib}/glymur*
%{python_sitelib}/Glymur-%{version}*-info

%changelog
* Thu Feb 11 2021 Benjamin Greiner <code@bnavigator.de>
- NEP 29: NumPy dropped Python 3.6 -- skip python36 build in TW
- Make importlib_resources conditional for Python < 3.7 (SLE/Leap)
* Sat Jan 23 2021 Benjamin Greiner <code@bnavigator.de>
- Update to 0.9.3
  * Qualify on Python 3.9
  * Qualify on OpenJPEG 2.4.0
  * Add support for multithreaded writes.
- Always require importlib_resources for tests: the new python36
  flavor on TW needs it, the python38 flavor is okay with it being
  installed.
* Tue Jul 14 2020 Matej Cepl <mcepl@suse.com>
- Don't install tests
* Thu Jul  9 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.9.2
  * Update setup.py to include tests in source distribution to PyPi
  * Update gdal imports to comply with GDAL recommendations.
* Tue May 26 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Mar 26 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.9.1
  * Removed support for python2.7
  * Fixed Cygwin support.
  * Fixed appveyor builds, Travis-CI framework reworked.
  * Some fragile tests removed.
  * Remove GDAL from setup.py requirements
* Mon Jan 13 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.8.19
  * Qualify on Python 3.8.
* Fri Dec  6 2019 Todd R <toddrme2178@gmail.com>
- Disable python2 support since dependencies dropped python2
- Use pytest to simplify test invocation
* Fri Sep 27 2019 Tomáš Chvátal <tchvatal@suse.com>
- Initial commit, needed by sunpy
